﻿Option Explicit On

Imports System
Imports System.Collections.Generic
Imports Console.Client.PurolatorWebServiceReference

Namespace WPF.Client
	Public Class ObjectHelper
		Public Shared Function GetRandomOrderRequest(credentials As CredentialInfo) As OrderRequestV3
			' Since this order does not have Saturday service selected, only Monday thru Friday are valid.
			Dim estShipDate As DateTime = DateTime.Today
			While (estShipDate.DayOfWeek = DayOfWeek.Saturday Or estShipDate.DayOfWeek = DayOfWeek.Sunday)
				estShipDate = estShipDate.AddDays(1)
			End While

			Dim request As OrderRequestV3 = New OrderRequestV3
			request.Credentials = credentials

			' The OrderNumber must be unique for non-voided orders for an Account.
			request.OrderNumber = "RndOrder-" + Guid.NewGuid().ToString().Replace("-", "").Substring(0, 10)
			' Ground shipping is available for most postal codes but only Air is available for some postal codes.
			request.ShipMethod = "GROUND"

			request.ShipFromAddress = New Address With {
			.Company = "My Company",
			.Add1 = "290 Spagnoli Road",
			.City = "Melville",
			.StateProv = "NY",
			.PostalCode = "11747",
			.Country = "US"}

			request.ShipToAddress = New Address With {
			.Name = "Test Customer Name",
			.Add1 = "560 Kings Road",
			.City = "Sydney",
			.StateProv = "NS",
			.PostalCode = "B1S1B8",
			.Country = "CA"}

			' LabelType indicates how we want to handle printing labels.
			' NONE: Do not mark the package label as printed; get labels later using a GetLabel request.
			' ZPL: Include the non-image ZPL code for printing the label - requires sending the response from a prior
			'	GetZPLInitializationImages request for the Purolator icons to be printed.
			' ZPLIMAGES: Include both the ZPL code for the Purolator icons and for the rest of the label.
			' IMAGE: Return the label as a PNG image encoded as a Base64 string.

			' Using the ZPL option is recommended since it substantially reduces the response size compared to ZPLIMAGES or IMAGE.
			' ZPLIMAGES is used in this demo code for simplicity.
			request.LabelType = "ZPLIMAGES"
			request.ShipDate = estShipDate

			Dim package As RequestPackageV3 = New RequestPackageV3 With {
			.PackageID = "PKG-" & Guid.NewGuid().ToString().Replace("-", "").Substring(0, 6),
			.WeightUOM = "LB",
			.Weight = 10.0}
			Dim packages(0) As RequestPackageV3
			packages(0) = package
			request.Packages = packages

			' Items are required if Purolator is handling customs; otherwise item information is ignored.
			Dim item = New RequestItemV3 With {
			.SKU = "x35135",
			.CustomsDesc = "Documents",
			.Quantity = 2,
			.TotalValue = 10,
			.Currency = "CAD",
			.CountryOfOrigin = "United States"}
			Dim items(0) As RequestItemV3
			items(0) = item
			request.Items = items

			Return request
		End Function

		Public Shared Function GetCloseoutRequest(credentials As CredentialInfo, packageIDs() As String) As CloseoutRequest
			Dim request As CloseoutRequest = New CloseoutRequest
			request.Credentials = credentials
			'' Indicate the packages we want to close out based on the PackageID field.
			'' We could instead provide Pins/Tracking numbers and set PackIDType to Pin
			request.PackageIDs = packageIDs
			request.PackIDType = "PackageID"
			request.SkidCount = 1
			request.ParsNumber = Guid.NewGuid().ToString().Substring(0, 12)

			Return request
		End Function
	End Class
End Namespace
